@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: cli.c 8808 2009-07-14 20:09:46Z charles $
+ * $Id: cli.c 8889 2009-08-10 20:04:08Z charles $
  *
  * Copyright (c) 2005-2006 Transmission authors and contributors
  *
@@ -300,8 +300,8 @@ main( int     argc,
     tr_torrent  * tor = NULL;
     tr_benc       settings;
     const char  * configDir;
-    tr_bool       haveSource; 
-    tr_bool       haveAnnounce; 
+    tr_bool       haveSource;
+    tr_bool       haveAnnounce;
 
     printf( "Transmission %s - http://www.transmissionbt.com/\n",
             LONG_VERSION_STRING );
@@ -439,6 +439,9 @@ main( int     argc,
     {
         char            line[LINEWIDTH];
         const tr_stat * st;
+        const char * messageName[] = { NULL, "Tracker gave a warning:",
+                                             "Tracker gave an error:",
+                                             "Error:" };
 
         tr_wait( 200 );
 
@@ -470,8 +473,9 @@ main( int     argc,
 
         getStatusStr( st, line, sizeof( line ) );
         printf( "\r%-*s", LINEWIDTH, line );
-        if( st->error )
-            fprintf( stderr, "\n%s\n", st->errorString );
+
+        if( messageName[st->error] )
+            fprintf( stderr, "\n%s: %s\n", messageName[st->error], st->errorString );
     }
 
 cleanup:
