@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: remote.c 8747 2009-06-25 01:57:31Z charles $
+ * $Id: remote.c 8982 2009-08-22 15:08:07Z charles $
  */
 
 #include <ctype.h> /* isspace */
@@ -40,7 +40,7 @@
 #define DEFAULT_HOST "localhost"
 #define DEFAULT_PORT atoi(TR_DEFAULT_RPC_PORT_STR)
 
-enum { TAG_SESSION, TAG_LIST, TAG_DETAILS, TAG_FILES, TAG_PEERS };
+enum { TAG_SESSION, TAG_STATS, TAG_LIST, TAG_DETAILS, TAG_FILES, TAG_PEERS };
 
 static const char*
 getUsage( void )
@@ -63,6 +63,15 @@ getUsage( void )
 static tr_option opts[] =
 {
     { 'a', "add",                  "Add torrent files by filename or URL", "a",  0, NULL },
+    { 970, "alt-speed",            "Use the alternate Limits", "as",  0, NULL },
+    { 971, "no-alt-speed",         "Don't use the alternate Limits", "AS",  0, NULL },
+    { 972, "alt-speed-downlimit",  "max alternate download speed (in KB/s)", "asd",  1, "<speed>" },
+    { 973, "alt-speed-uplimit",    "max alternate upload speed (in KB/s)", "asu",  1, "<speed>" },
+    { 974, "alt-speed-scheduler",  "Use the scheduled on/off times", "asc",  0, NULL },
+    { 975, "no-alt-speed-scheduler","Don't use the scheduled on/off times", "ASC",  0, NULL },
+    { 976, "alt-speed-time-begin", "Time to start using the alt speed limits (in hhmm)", NULL,  1, "<time>" },
+    { 977, "alt-speed-time-end",   "Time to stop using the alt speed limits (in hhmm)", NULL,  1, "<time>" },
+    { 978, "alt-speed-days",       "Numbers for any/all days of the week - eg. \"1-7\"", NULL,  1, "<days>" },
     { 'b', "debug",                "Print debugging information", "b",  0, NULL },
     { 'd', "downlimit",            "Set the maximum global download speed in KB/s", "d",  1, "<speed>" },
     { 'D', "no-downlimit",         "Don't limit the global download speed", "D",  0, NULL },
@@ -74,6 +83,7 @@ static tr_option opts[] =
     { 'G', "no-get",               "Mark files for not downloading", "G",  1, "<files>" },
     { 'i', "info",                 "Show the current torrent(s)' details", "i",  0, NULL },
     { 920, "session-info",         "Show the session's details", "si", 0, NULL },
+    { 921, "session-stats",        "Show the session's statistics", "st", 0, NULL },
     { 'l', "list",                 "List all torrents", "l",  0, NULL },
     { 960, "move",                 "Move current torrent's data to a new folder", NULL, 1, "<path>" },
     { 961, "find",                 "Tell Transmission where to find a torrent's data", NULL, 1, "<path>" },
@@ -209,6 +219,58 @@ addIdArg( tr_benc *    args,
     }
 }
 
+static void
+addTime( tr_benc * args, const char * key, const char * arg )
+{
+    int time;
+    tr_bool success = FALSE;
+
+    if( arg && ( strlen( arg ) == 4 ) )
+    {
+        const char hh[3] = { arg[0], arg[1], '\0' };
+        const char mm[3] = { arg[2], arg[3], '\0' };
+        const int hour = atoi( hh );
+        const int min = atoi( mm );
+
+        if( 0<=hour && hour<24 && 0<=min && min<60 )
+        {
+            time = min + ( hour * 60 );
+            success = TRUE;
+        }
+    }
+
+    if( success )
+        tr_bencDictAddInt( args, key, time );
+    else
+        fprintf( stderr, "Please specify the time of day in 'hhmm' format.\n" );
+}
+
+static void
+addDays( tr_benc * args, const char * key, const char * arg )
+{
+    int days = 0;
+
+    if( arg )
+    {
+        int i;
+        int valueCount;
+        int * values = tr_parseNumberRange( arg, -1, &valueCount );
+        for( i=0; i<valueCount; ++i )
+        {
+            if ( values[i] < 0 || values[i] > 7 ) continue;
+            if ( values[i] == 7 ) values[i] = 0;
+
+            days |= 1 << values[i];
+        }
+        tr_free( values );
+    }
+
+    if ( days )
+        tr_bencDictAddInt( args, key, days );
+    else
+        fprintf( stderr, "Please specify the days of the week in '1-3,4,7' format.\n" );
+}
+
 static void
 addFiles( tr_benc *    args,
           const char * key,
@@ -253,6 +315,7 @@ static const char * details_keys[] = {
     "doneDate",
     "downloadDir",
     "downloadedEver",
+    "error",
     "errorString",
     "eta",
     "hashString",
@@ -371,6 +434,51 @@ readargs( int           argc,
                 tr_bencDictAddBool( args, TR_PREFS_KEY_DSPEED_ENABLED, FALSE );
                 break;
 
+            case 970:
+                tr_bencDictAddStr( &top, "method", "session-set" );
+                tr_bencDictAddBool( args, TR_PREFS_KEY_ALT_SPEED_ENABLED, TRUE );
+                break;
+
+            case 971:
+                tr_bencDictAddStr( &top, "method", "session-set" );
+                tr_bencDictAddBool( args, TR_PREFS_KEY_ALT_SPEED_ENABLED, FALSE );
+                break;
+
+            case 972:
+                tr_bencDictAddStr( &top, "method", "session-set" );
+                tr_bencDictAddInt( args, TR_PREFS_KEY_ALT_SPEED_DOWN, numarg( optarg ) );
+                break;
+
+            case 973:
+                tr_bencDictAddStr( &top, "method", "session-set" );
+                tr_bencDictAddInt( args, TR_PREFS_KEY_ALT_SPEED_UP, numarg( optarg ) );
+                break;
+
+            case 974:
+                tr_bencDictAddStr( &top, "method", "session-set" );
+                tr_bencDictAddBool( args, TR_PREFS_KEY_ALT_SPEED_TIME_ENABLED, TRUE );
+                break;
+
+            case 975:
+                tr_bencDictAddStr( &top, "method", "session-set" );
+                tr_bencDictAddBool( args, TR_PREFS_KEY_ALT_SPEED_TIME_ENABLED, FALSE );
+                break;
+
+            case 976:
+                tr_bencDictAddStr( &top, "method", "session-set" );
+                addTime( args, TR_PREFS_KEY_ALT_SPEED_TIME_BEGIN, optarg);
+                break;
+
+            case 977:
+                tr_bencDictAddStr( &top, "method", "session-set" );
+                addTime( args, TR_PREFS_KEY_ALT_SPEED_TIME_END, optarg);
+                break;
+
+            case 978:
+                tr_bencDictAddStr( &top, "method", "session-set" );
+                addDays( args, TR_PREFS_KEY_ALT_SPEED_TIME_DAY, optarg );
+                break;
+
             case 'f':
                 tr_bencDictAddStr( &top, "method", "torrent-get" );
                 tr_bencDictAddInt( &top, "tag", TAG_FILES );
@@ -555,6 +663,11 @@ readargs( int           argc,
                 tr_bencDictAddInt( &top, "tag", TAG_SESSION );
                 break;
 
+            case 921:
+                tr_bencDictAddStr( &top, "method", "session-stats" );
+                tr_bencDictAddInt( &top, "tag", TAG_STATS );
+                break;
+                
             case 930:
                 tr_bencDictAddStr( &top, "method", "torrent-set" );
                 addIdArg( args, id );
@@ -683,20 +796,65 @@ writeFunc( void * ptr,
     return byteCount;
 }
 
-static void
-etaToString( char *  buf,
-             size_t  buflen,
-             int64_t eta )
+
+static void 
+etaToString( char *  buf, size_t  buflen, int64_t eta ) 
+{ 
+    if( eta < 0 )
+        tr_snprintf( buf, buflen, "Unknown" ); 
+    else if( eta < 60 )
+        tr_snprintf( buf, buflen, "%" PRId64 "sec", eta ); 
+    else if( eta < ( 60 * 60 ) )
+        tr_snprintf( buf, buflen, "%" PRId64 " min", eta / 60 ); 
+    else if( eta < ( 60 * 60 * 24 ) )
+        tr_snprintf( buf, buflen, "%" PRId64 " hrs", eta / ( 60 * 60 ) ); 
+    else
+        tr_snprintf( buf, buflen, "%" PRId64 " days", eta / ( 60 * 60 * 24 ) ); 
+} 
+
+static char*
+tr_strltime( char * buf, int seconds, size_t buflen )
 {
-    if( eta < 0 ) tr_snprintf( buf, buflen, "Unknown" );
-    else if( eta < 60 ) tr_snprintf( buf, buflen, "%" PRId64 "sec", eta );
-    else if( eta <
-            ( 60 * 60 ) ) tr_snprintf( buf, buflen, "%" PRId64 " min",
-                                       eta / 60 );
-    else if( eta <
-            ( 60 * 60 * 24 ) ) tr_snprintf( buf, buflen, "%" PRId64 " hrs",
-                                           eta / ( 60 * 60 ) );
-    else tr_snprintf( buf, buflen, "%" PRId64 " days", eta / ( 60 * 60 * 24 ) );
+    int  days, hours, minutes;
+    char d[128], h[128], m[128], s[128];
+
+    if( seconds < 0 )
+        seconds = 0;
+
+    days = seconds / 86400;
+    hours = ( seconds % 86400 ) / 3600;
+    minutes = ( seconds % 3600 ) / 60;
+    seconds = ( seconds % 3600 ) % 60;
+
+    tr_snprintf( d, sizeof( d ), "%'d day%s", days, days==1?"":"s" );
+    tr_snprintf( h, sizeof( h ), "%'d hour%s", hours, hours==1?"":"s" );
+    tr_snprintf( m, sizeof( m ), "%'d minute%s", minutes, minutes==1?"":"s" );
+    tr_snprintf( s, sizeof( s ), "%'d second%s", seconds, seconds==1?"":"s" );
+
+    if( days )
+    {
+        if( days >= 4 || !hours )
+            tr_strlcpy( buf, d, buflen );
+        else
+            tr_snprintf( buf, buflen, "%s, %s", d, h );
+    }
+    else if( hours )
+    {
+        if( hours >= 4 || !minutes )
+            tr_strlcpy( buf, h, buflen );
+        else
+            tr_snprintf( buf, buflen, "%s, %s", h, m );
+    }
+    else if( minutes )
+    {
+        if( minutes >= 4 || !seconds )
+            tr_strlcpy( buf, m, buflen );
+        else
+            tr_snprintf( buf, buflen, "%s, %s", m, s );
+    }
+    else tr_strlcpy( buf, s, buflen );
+
+    return buf;
 }
 
 #define KILOBYTE_FACTOR 1024.0
@@ -787,23 +945,23 @@ getStatusString( tr_benc * t, char * buf, size_t buflen )
 
         case TR_STATUS_DOWNLOAD:
         case TR_STATUS_SEED: {
-	    int64_t fromUs = 0; 
-	    int64_t toUs = 0; 
- 	    tr_bencDictFindInt( t, "peersGettingFromUs", &fromUs ); 
- 	    tr_bencDictFindInt( t, "peersSendingToUs", &toUs ); 
- 	    if( fromUs && toUs ) 
- 	        tr_strlcpy( buf, "Up & Down", buflen ); 
- 	    else if( toUs ) 
- 	        tr_strlcpy( buf, "Downloading", buflen ); 
- 	    else if( fromUs ) { 
- 	        int64_t leftUntilDone = 0; 
- 	        tr_bencDictFindInt( t, "leftUntilDone", &leftUntilDone ); 
- 	        if( leftUntilDone > 0 )
- 	            tr_strlcpy( buf, "Uploading", buflen ); 
- 	        else
- 	            tr_strlcpy( buf, "Seeding", buflen ); 
- 	    } else {
- 	        tr_strlcpy( buf, "Idle", buflen ); 
+            int64_t fromUs = 0;
+            int64_t toUs = 0;
+            tr_bencDictFindInt( t, "peersGettingFromUs", &fromUs );
+            tr_bencDictFindInt( t, "peersSendingToUs", &toUs );
+            if( fromUs && toUs )
+                tr_strlcpy( buf, "Up & Down", buflen );
+            else if( toUs )
+                tr_strlcpy( buf, "Downloading", buflen );
+            else if( fromUs ) {
+                int64_t leftUntilDone = 0;
+                tr_bencDictFindInt( t, "leftUntilDone", &leftUntilDone );
+                if( leftUntilDone > 0 )
+                    tr_strlcpy( buf, "Uploading", buflen );
+                else
+                    tr_strlcpy( buf, "Seeding", buflen );
+            } else {
+                tr_strlcpy( buf, "Idle", buflen );
             }
             break;
         }
@@ -918,6 +1076,43 @@ printSession( tr_benc * top )
     }
 }
 
+static void
+printSessionStats( tr_benc * top )
+{
+    tr_benc *args, *d;
+    if( ( tr_bencDictFindDict( top, "arguments", &args ) ) )
+    {
+        char buf[512];
+        int64_t up, down, secs, sessions;
+
+        if( tr_bencDictFindDict( args, "current-stats", &d )
+            && tr_bencDictFindInt( d, "uploadedBytes", &up )
+            && tr_bencDictFindInt( d, "downloadedBytes", &down )
+            && tr_bencDictFindInt( d, "secondsActive", &secs ) )
+        {
+            printf( "\nCURRENT SESSION\n" );
+            printf( "  Uploaded:   %s\n", strlsize( buf, up, sizeof( buf ) ) );
+            printf( "  Downloaded: %s\n", strlsize( buf, down, sizeof( buf ) ) );
+            printf( "  Ratio:      %s\n", strlratio( buf, up, down, sizeof( buf ) ) );
+            printf( "  Duration:   %s\n", tr_strltime( buf, secs, sizeof( buf ) ) );
+        }
+
+        if( tr_bencDictFindDict( args, "cumulative-stats", &d )
+            && tr_bencDictFindInt( d, "sessionCount", &sessions )
+            && tr_bencDictFindInt( d, "uploadedBytes", &up )
+            && tr_bencDictFindInt( d, "downloadedBytes", &down )
+            && tr_bencDictFindInt( d, "secondsActive", &secs ) )
+        {
+            printf( "\nTOTAL\n" );
+            printf( "  Started %lu times\n", (unsigned long)sessions );
+            printf( "  Uploaded:   %s\n", strlsize( buf, up, sizeof( buf ) ) );
+            printf( "  Downloaded: %s\n", strlsize( buf, down, sizeof( buf ) ) );
+            printf( "  Ratio:      %s\n", strlratio( buf, up, down, sizeof( buf ) ) );
+            printf( "  Duration:   %s\n", tr_strltime( buf, secs, sizeof( buf ) ) );
+        }
+    }
+}
+
 static void
 printDetails( tr_benc * top )
 {
@@ -967,10 +1162,7 @@ printDetails( tr_benc * top )
             }
 
             if( tr_bencDictFindInt( t, "eta", &i ) )
-            {
-                etaToString( buf, sizeof( buf ), i );
-                printf( "  ETA: %s\n", buf );
-            }
+                printf( "  ETA: %s\n", tr_strltime( buf, i, sizeof( buf ) ) );
             if( tr_bencDictFindInt( t, "rateDownload", &i ) )
                 printf( "  Download Speed: %.1f KB/s\n", i / 1024.0 );
             if( tr_bencDictFindInt( t, "rateUpload", &i ) )
@@ -1005,9 +1197,16 @@ printDetails( tr_benc * top )
                 strlsize( buf, i, sizeof( buf ) );
                 printf( "  Corrupt DL: %s\n", buf );
             }
-            if( tr_bencDictFindStr( t, "errorString", &str ) && str && *str )
-                printf( "  Error: %s\n", str );
-
+            if( tr_bencDictFindStr( t, "errorString", &str ) && str && *str &&
+                tr_bencDictFindInt( t, "error", &i ) && i )
+            {
+                switch( i ) {
+                    case TR_STAT_TRACKER_WARNING: printf( "  Tracker gave a warning: %s\n", str ); break;
+                    case TR_STAT_TRACKER_ERROR:   printf( "  Tracker gave an error: %s\n", str ); break;
+                    case TR_STAT_LOCAL_ERROR:     printf( "  Error: %s\n", str ); break;
+                    default: break; /* no error */
+                }
+            }
             if( tr_bencDictFindInt( t, "peersConnected", &i )
               && tr_bencDictFindInt( t, "peersGettingFromUs", &j )
               && tr_bencDictFindInt( t, "peersSendingToUs", &k ) )
@@ -1282,7 +1481,7 @@ printTorrentList( tr_benc * top )
 
                 strlsize( haveStr, sizeWhenDone - leftUntilDone, sizeof( haveStr ) );
 
-                if( leftUntilDone )
+                if( leftUntilDone || eta != -1 )
                     etaToString( etaStr, sizeof( etaStr ), eta );
                 else
                     tr_snprintf( etaStr, sizeof( etaStr ), "Done" );
@@ -1345,6 +1544,9 @@ processResponse( const char * host,
             case TAG_SESSION:
                 printSession( &top ); break;
 
+            case TAG_STATS:
+                printSessionStats( &top ); break;
+
             case TAG_FILES:
                 printFileList( &top ); break;
 
@@ -1421,7 +1623,7 @@ tr_curl_easy_init( struct evbuffer * writebuf )
     }
     return curl;
 }
-    
+
 
 static int
 processRequests( const char *  host,
@@ -1511,7 +1713,7 @@ main( int     argc,
         showUsage( );
         return EXIT_FAILURE;
     }
-        
+
 
     for( i=0; i<reqCount; ++i )
         tr_free( reqs[i] );
