@@ -7,16 +7,20 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: details.h 7664 2009-01-11 17:46:51Z charles $
+ * $Id: details.h 8279 2009-04-24 01:37:04Z charles $
  */
 
 #ifndef GTK_TORRENT_INSPECTOR_H
 #define GTK_TORRENT_INSPECTOR_H
 
 #include <gtk/gtk.h>
+#include "tr-core.h"
 #include "tr-torrent.h"
 
 GtkWidget* torrent_inspector_new( GtkWindow * parent,
-                                  TrTorrent * tor );
+                                  TrCore    * core );
+
+void torrent_inspector_set_torrents( GtkWidget * widgets,
+                                     GSList    * torrent_ids );
 
 #endif /* TG_PREFS_H */
