@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: main.c 9093 2009-09-10 17:39:44Z charles $
+ * $Id: main.c 9880 2010-01-04 23:06:34Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -259,32 +259,29 @@ onMainWindowSizeAllocated( GtkWidget *            window,
 }
 
 static sig_atomic_t global_sigcount = 0;
+static struct cbdata * sighandler_cbdata = NULL;
 
 static void
-fatalsig( int sig )
+signal_handler( int sig )
 {
-    /* revert to default handler after this many */
-    static const int SIGCOUNT_MAX = 3;
-
-    if( ++global_sigcount >= SIGCOUNT_MAX )
+    if( ++global_sigcount > 1 )
     {
         signal( sig, SIG_DFL );
         raise( sig );
     }
+    else switch( sig )
+    {
+        case SIGINT:
+            g_message( _( "Got signal %d; trying to shut down cleanly.  Do it again if it gets stuck." ), sig );
+            doAction( "quit", sighandler_cbdata );
+            break;
+    }
 }
 
 static void
 setupsighandlers( void )
 {
-#ifdef G_OS_WIN32
-    const int sigs[] = { SIGINT, SIGTERM };
-#else
-    const int sigs[] = { SIGHUP, SIGINT, SIGQUIT, SIGTERM };
-#endif
-    guint     i;
-
-    for( i = 0; i < G_N_ELEMENTS( sigs ); ++i )
-        signal( sigs[i], fatalsig );
+    signal( SIGINT, signal_handler );
 }
 
 static tr_rpc_callback_status
@@ -434,11 +431,13 @@ main( int argc, char ** argv )
         tr_session * session;
         struct cbdata * cbdata = g_new0( struct cbdata, 1 );
 
+        sighandler_cbdata = cbdata;
+
         /* ensure the directories are created */
-       if(( str = pref_string_get( PREF_KEY_DIR_WATCH )))
-           gtr_mkdir_with_parents( str, 0777 );
-       if(( str = pref_string_get( TR_PREFS_KEY_DOWNLOAD_DIR )))
-           gtr_mkdir_with_parents( str, 0777 );
+        if(( str = pref_string_get( PREF_KEY_DIR_WATCH )))
+            gtr_mkdir_with_parents( str, 0777 );
+        if(( str = pref_string_get( TR_PREFS_KEY_DOWNLOAD_DIR )))
+            gtr_mkdir_with_parents( str, 0777 );
 
         /* initialize the libtransmission session */
         session = tr_sessionInit( "gtk", configDir, TRUE, pref_get_all( ) );
@@ -538,9 +537,10 @@ appsetup( TrWindow *      wind,
         gtk_widget_show( GTK_WIDGET( wind ) );
     else
     {
-        gtk_window_iconify( wind );
         gtk_window_set_skip_taskbar_hint( cbdata->wind,
                                           cbdata->icon != NULL );
+        cbdata->isIconified = FALSE; // ensure that the next toggle iconifies
+        action_toggle( "toggle-main-window", FALSE );
     }
 }
 
@@ -627,13 +627,10 @@ winsetup( struct cbdata * cbdata,
     setupdrag( GTK_WIDGET( wind ), cbdata );
 }
 
-static gpointer
-quitThreadFunc( gpointer gdata )
+static gboolean
+onSessionClosed( gpointer gdata )
 {
     struct cbdata * cbdata = gdata;
-    gdk_threads_enter( );
-
-    tr_core_close( cbdata->core );
 
     /* shutdown the gui */
     if( cbdata->details ) {
@@ -658,8 +655,21 @@ quitThreadFunc( gpointer gdata )
     g_free( cbdata );
 
     gtk_main_quit( );
-    gdk_threads_leave( );
 
+    return FALSE;
+}
+
+static gpointer
+sessionCloseThreadFunc( gpointer gdata )
+{
+    /* since tr_sessionClose() is a blocking function,
+     * call it from another thread... when it's done,
+     * punt the GUI teardown back to the GTK+ thread */
+    struct cbdata * cbdata = gdata;
+    gdk_threads_enter( );
+    tr_core_close( cbdata->core );
+    gtr_idle_add( onSessionClosed, gdata );
+    gdk_threads_leave( );
     return NULL;
 }
 
@@ -726,7 +736,7 @@ wannaquit( gpointer vdata )
                                    pref_int_get( PREF_KEY_MAIN_WINDOW_Y ) );
 
     /* shut down libT */
-    g_thread_create( quitThreadFunc, vdata, TRUE, NULL );
+    g_thread_create( sessionCloseThreadFunc, vdata, TRUE, NULL );
 }
 
 static void
