@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: tr-core.c 8907 2009-08-13 03:52:21Z charles $
+ * $Id: tr-core.c 9070 2009-09-08 18:59:48Z charles $
  *
  * Copyright (c) 2007-2008 Transmission authors and contributors
  *
@@ -418,7 +418,7 @@ setSort( TrCore *     core,
         sort_func = compareByAge;
     else if( !strcmp( mode, "sort-by-progress" ) )
         sort_func = compareByProgress;
-    else if( !strcmp( mode, "sort-by-eta" ) )
+    else if( !strcmp( mode, "sort-by-time-left" ) )
         sort_func = compareByETA;
     else if( !strcmp( mode, "sort-by-ratio" ) )
         sort_func = compareByRatio;
