@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: tr-torrent.c 7861 2009-02-09 20:11:32Z charles $
+ * $Id: tr-torrent.c 8808 2009-07-14 20:09:46Z charles $
  *
  * Copyright (c) 2006-2008 Transmission authors and contributors
  *
@@ -29,6 +29,7 @@
 #include <glib/gi18n.h>
 
 #include <libtransmission/transmission.h>
+#include <libtransmission/utils.h> /* tr_truncd() */
 
 #include "tr-prefs.h"
 #include "tr-torrent.h"
@@ -167,7 +168,7 @@ completenessChangedCallback( tr_torrent       * tor,
                              void *             user_data )
 {
     if( ( completeness != TR_LEECH ) && ( tr_torrentStat( tor )->sizeWhenDone != 0 ) )
-        g_idle_add( notifyInMainThread, user_data );
+        gtr_idle_add( notifyInMainThread, user_data );
 }
 
 static TrTorrent *
@@ -198,7 +199,7 @@ tr_torrent_new_ctor( tr_session   * session,
      * doesn't have any concept of the glib trash API */
     tr_ctorGetDeleteSource( ctor, &doTrash );
     tr_ctorSetDeleteSource( ctor, FALSE );
-    tor = tr_torrentNew( session, ctor, errcode );
+    tor = tr_torrentNew( ctor, errcode );
 
     if( tor && doTrash )
     {
@@ -229,16 +230,14 @@ tr_torrent_status_str( TrTorrent * gtor )
     {
         case TR_STATUS_CHECK_WAIT:
             top =
-                g_strdup_printf( _(
-                                     "Waiting to verify local data (%.1f%% tested)" ),
-                                 st->recheckProgress * 100.0 );
+                g_strdup_printf( _( "Waiting to verify local data (%.1f%% tested)" ),
+                                 tr_truncd( 100 * st->recheckProgress, 1 ) );
             break;
 
         case TR_STATUS_CHECK:
             top =
-                g_strdup_printf( _(
-                                     "Verifying local data (%.1f%% tested)" ),
-                                 st->recheckProgress * 100.0 );
+                g_strdup_printf( _( "Verifying local data (%.1f%% tested)" ),
+                                 tr_truncd( 100 * st->recheckProgress, 1 ) );
             break;
 
         case TR_STATUS_DOWNLOAD:
