@@ -2,9 +2,13 @@
 #define TRACKER_LIST_H
 
 #include <gtk/gtk.h>
-#include "tr-torrent.h"
+#include <libtransmission/transmission.h>
 
-GtkWidget*       tracker_list_new( TrTorrent * gtor );
+void tracker_list_set_torrent( GtkWidget*, int torrentId );
+
+void tracker_list_clear( GtkWidget* );
+
+GtkWidget* tracker_list_new( tr_session*, int torrentId, gboolean isNew );
 
 /**
  * @return an array of tr_tracker_info's.  It's the caller's responsibility
@@ -17,4 +21,5 @@ void tracker_list_add_trackers( GtkWidget             * list,
                                 const tr_tracker_info * trackers,
                                 int                     trackerCount );
 
+
 #endif
