@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: util.c 8941 2009-08-15 21:14:44Z charles $
+ * $Id: util.c 9093 2009-09-10 17:39:44Z charles $
  */
 
 #include <ctype.h> /* isxdigit() */
@@ -504,9 +504,12 @@ gtr_open_file( const char * path )
         if( !opened )
         {
             char * argv[] = { (char*)"xdg-open", (char*)path, NULL };
-            g_spawn_async( NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
-                           NULL, NULL, NULL, NULL );
+            opened = g_spawn_async( NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
+                                    NULL, NULL, NULL, NULL );
         }
+
+        if( !opened )
+            g_message( "Unable to open \"%s\"", path );
     }
 }
 
