@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: bencode.c 8903 2009-08-12 14:40:32Z charles $
+ * $Id: bencode.c 9051 2009-09-07 06:19:26Z charles $
  */
 
 #include <assert.h>
@@ -1339,9 +1339,7 @@ jsonStringFunc( const tr_benc * val, void * vdata )
                     UTF32        buf = 0;
                     UTF32 *      u32 = &buf;
                     ConversionResult result = ConvertUTF8toUTF32( &tmp, end, &u32, &buf + 1, 0 );
-                    if( ( result != conversionOK ) && ( tmp == it ) )
-                        ++it; /* it's beyond help; skip it */
-                    else {
+                    if((( result==conversionOK ) || (result==targetExhausted)) && (tmp!=it)) { 
                         evbuffer_add_printf( data->out, "\\u%04x", (unsigned int)buf );
                         it = tmp - 1;
                     }
