@@ -3,11 +3,11 @@
  *
  * This file is licensed by the GPL version 2.  Works owned by the
  * Transmission project are granted a special exemption to clause 2(b)
- * so that the bulk of its code can remain under the MIT license. 
+ * so that the bulk of its code can remain under the MIT license.
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: completion.h 7722 2009-01-16 17:31:10Z charles $
+ * $Id: completion.h 8889 2009-08-10 20:04:08Z charles $
  */
 
 #ifndef TR_COMPLETION_H
@@ -20,6 +20,7 @@
 #include <assert.h>
 
 #include "transmission.h"
+#include "bitfield.h"
 #include "utils.h" /* tr_bitfield */
 
 typedef struct tr_completion
@@ -109,7 +110,8 @@ static TR_INLINE float tr_cpPercentComplete( const tr_completion * cp )
 
 static TR_INLINE float tr_cpPercentDone( const tr_completion * cp )
 {
-    return tr_getRatio( cp->sizeNow, tr_cpSizeWhenDone( cp ) );
+    const double ratio = tr_getRatio( cp->sizeNow, tr_cpSizeWhenDone( cp ) );
+    return (ratio == TR_RATIO_NA ||  ratio == TR_RATIO_INF) ? 0.0f : ratio;
 }
 
 /**
@@ -134,7 +136,13 @@ tr_bool tr_cpFileIsComplete( const tr_completion * cp, tr_file_index_t );
 *** Blocks
 **/
 
-static TR_INLINE tr_bool tr_cpBlockIsComplete( const tr_completion * cp, tr_block_index_t block ) {
+static TR_INLINE tr_bool tr_cpBlockIsCompleteFast( const tr_completion * cp, tr_block_index_t block )
+{
+    return tr_bitfieldHasFast( &cp->blockBitfield, block );
+}
+
+static TR_INLINE tr_bool tr_cpBlockIsComplete( const tr_completion * cp, tr_block_index_t block )
+{
     return tr_bitfieldHas( &cp->blockBitfield, block );
 }
 
