@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: crypto.h 7664 2009-01-11 17:46:51Z charles $
+ * $Id: crypto.h 8903 2009-08-12 14:40:32Z charles $
  */
 
 #ifndef TR_ENCRYPTION_H
@@ -26,6 +26,12 @@
 **/
 
 struct evbuffer;
+
+/**
+ * @addtogroup utils Utilities
+ * @{
+ */
+
 typedef struct tr_crypto tr_crypto;
 
 /**
@@ -92,7 +98,12 @@ int            tr_cryptoRandInt( int n );
 int            tr_cryptoWeakRandInt( int n );
 
 /** Fills a buffer with random bytes */
-void           tr_cryptoRandBuf( unsigned char *buf,
-                                 size_t         len );
+void           tr_cryptoRandBuf( void * buf, size_t len );
+
+char*          tr_ssha1( const void * plaintext );
+
+tr_bool        tr_ssha1_matches( const char * source, const char * pass );
+
+/* @} */
 
 #endif
