@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: handshake.c 8889 2009-08-10 20:04:08Z charles $
+ * $Id: handshake.c 9366 2009-10-22 02:50:59Z charles $
  */
 
 #include <assert.h>
@@ -312,7 +312,8 @@ parseHandshake( tr_handshake *    handshake,
 
     tr_peerIoEnableFEXT( handshake->io, HANDSHAKE_HAS_FASTEXT( reserved ) );
 
-    /* This doesn't depend on whether the torrent is private. */
+    /* This is independent of whether or not DHT is actually used.
+     * it's okay to set this flag even for private torrents */
     if( tor && tr_sessionAllowsDHT( tor->session ) )
         tr_peerIoEnableDHT( handshake->io, HANDSHAKE_HAS_DHT( reserved ) );
 
@@ -674,6 +675,11 @@ readHandshake( tr_handshake *    handshake,
 
     tr_peerIoEnableFEXT( handshake->io, HANDSHAKE_HAS_FASTEXT( reserved ) );
 
+    /* This is independent of whether or not DHT is actually used.
+     * it's okay to set this flag even for private torrents */
+    if( tr_sessionAllowsDHT( handshake->session ) )
+        tr_peerIoEnableDHT( handshake->io, HANDSHAKE_HAS_DHT( reserved ) );
+
     /* torrent hash */
     tr_peerIoReadBytes( handshake->io, inbuf, hash, sizeof( hash ) );
     if( tr_peerIoIsIncoming( handshake->io ) )
