@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: inout.c 8725 2009-06-21 07:36:51Z charles $
+ * $Id: inout.c 8935 2009-08-15 15:52:10Z charles $
  */
 
 #include <assert.h>
@@ -39,7 +39,7 @@
   #undef read
  #endif
  #define read  _read
- 
+
  #if defined(write)
   #undef write
  #endif
@@ -113,9 +113,6 @@ readOrWriteBytes( const tr_torrent * tor,
     if( ( !err ) && ( !fileExists ) && ( ioMode == TR_IO_WRITE ) )
         tr_statsFileCreated( tor->session );
 
-    if( fd >= 0 )
-        tr_fdFileReturn( fd );
-
     return err;
 }
 
@@ -155,11 +152,11 @@ tr_ioFindFileLocation( const tr_torrent * tor,
 
 /* returns 0 on success, or an errno on failure */
 static int
-readOrWritePiece( const tr_torrent * tor,
+readOrWritePiece( tr_torrent       * tor,
                   int                ioMode,
                   tr_piece_index_t   pieceIndex,
                   uint32_t           pieceOffset,
-                  uint8_t *          buf,
+                  uint8_t          * buf,
                   size_t             buflen )
 {
     int             err = 0;
@@ -185,27 +182,33 @@ readOrWritePiece( const tr_torrent * tor,
         buflen -= bytesThisPass;
         ++fileIndex;
         fileOffset = 0;
+
+        if( err ) {
+            char * path = tr_buildPath( tor->downloadDir, file->name, NULL );
+            tr_torrentSetLocalError( tor, "%s (%s)", tr_strerror( err ), path );
+            tr_free( path );
+        }
     }
 
     return err;
 }
 
 int
-tr_ioRead( const tr_torrent * tor,
+tr_ioRead( tr_torrent       * tor,
            tr_piece_index_t   pieceIndex,
            uint32_t           begin,
            uint32_t           len,
-           uint8_t *          buf )
+           uint8_t          * buf )
 {
     return readOrWritePiece( tor, TR_IO_READ, pieceIndex, begin, buf, len );
 }
 
 int
-tr_ioWrite( const tr_torrent * tor,
+tr_ioWrite( tr_torrent       * tor,
             tr_piece_index_t   pieceIndex,
             uint32_t           begin,
             uint32_t           len,
-            const uint8_t *    buf )
+            const uint8_t    * buf )
 {
     return readOrWritePiece( tor, TR_IO_WRITE, pieceIndex, begin,
                              (uint8_t*)buf,
@@ -217,11 +220,11 @@ tr_ioWrite( const tr_torrent * tor,
 ****/
 
 static tr_bool
-recalculateHash( const tr_torrent * tor,
+recalculateHash( tr_torrent       * tor,
                  tr_piece_index_t   pieceIndex,
                  void             * buffer,
                  size_t             buflen,
-                 uint8_t *          setme )
+                 uint8_t          * setme )
 {
     size_t   bytesLeft;
     uint32_t offset = 0;
@@ -263,7 +266,7 @@ recalculateHash( const tr_torrent * tor,
 }
 
 tr_bool
-tr_ioTestPiece( const tr_torrent  * tor,
+tr_ioTestPiece( tr_torrent        * tor,
                 tr_piece_index_t    pieceIndex,
                 void              * buffer,
                 size_t              buflen )
