@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: json.c 7963 2009-02-27 00:57:44Z charles $
+ * $Id: json.c 8585 2009-06-01 18:57:37Z charles $
  */
 
 #include <assert.h>
@@ -92,14 +92,9 @@ callback( void *             vdata,
             break;
 
         case JSON_T_FLOAT:
-        {
-            char buf[128];
-            tr_snprintf( buf, sizeof( buf ), "%f",
-                         (double)value->vu.float_value );
-            tr_bencInitStr( getNode( data ), buf, -1 );
             data->hasContent = TRUE;
+            tr_bencInitReal( getNode( data ), (double)value->vu.float_value );
             break;
-        }
 
         case JSON_T_NULL:
             data->hasContent = TRUE;
@@ -113,12 +108,12 @@ callback( void *             vdata,
 
         case JSON_T_TRUE:
             data->hasContent = TRUE;
-            tr_bencInitInt( getNode( data ), 1 );
+            tr_bencInitBool( getNode( data ), 1 );
             break;
 
         case JSON_T_FALSE:
             data->hasContent = TRUE;
-            tr_bencInitInt( getNode( data ), 0 );
+            tr_bencInitBool( getNode( data ), 0 );
             break;
 
         case JSON_T_STRING:
@@ -139,7 +134,8 @@ callback( void *             vdata,
 }
 
 int
-tr_jsonParse( const void     * vbuf,
+tr_jsonParse( const char     * source,
+              const void     * vbuf,
               size_t           len,
               tr_benc        * setme_benc,
               const uint8_t ** setme_end )
@@ -149,7 +145,7 @@ tr_jsonParse( const void     * vbuf,
     int                         err = 0;
     const unsigned char       * buf = vbuf;
     const void                * bufend = buf + len;
-    struct JSON_config_struct   config;
+    JSON_config                 config;
     struct JSON_parser_struct * checker;
     struct json_benc_data       data;
 
@@ -175,7 +171,10 @@ tr_jsonParse( const void     * vbuf,
     }
 
     if( buf != bufend ) {
-        tr_err( "JSON parser failed at line %d, column %d: \"%.16s\"", line, column, buf );
+        if( source )
+            tr_err( "JSON parser failed in %s at line %d, column %d: \"%.16s\"", source, line, column, buf );
+        else
+            tr_err( "JSON parser failed at line %d, column %d: \"%.16s\"", line, column, buf );
         err = EILSEQ;
     }
 
