@@ -7,14 +7,24 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: json.h 7664 2009-01-11 17:46:51Z charles $
+ * $Id: json.h 8585 2009-06-01 18:57:37Z charles $
  */
 
 #ifndef TR_JSON_H
 
-int tr_jsonParse( const void *     vbuf,
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+/** @ingroup tr_benc */
+int tr_jsonParse( const char * source, /* such as a filename.  only when logging an error */
+                  const void *     vbuf,
                   size_t           len,
                   struct tr_benc * setme_benc,
                   const uint8_t ** setme_end );
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
