@@ -7,12 +7,16 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: makemeta.h 7664 2009-01-11 17:46:51Z charles $
+ * $Id: makemeta.h 8182 2009-04-08 20:57:47Z charles $
  */
 
 #ifndef TR_MAKEMETA_H
 #define TR_MAKEMETA_H 1
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct tr_metainfo_builder_file
 {
     char *      filename;
@@ -45,7 +49,6 @@ typedef struct tr_metainfo_builder
     uint32_t                    pieceSize;
     uint32_t                    pieceCount;
     int                         isSingleFile;
-    tr_session *                handle;
 
     /**
     ***  These are set inside tr_makeMetaInfo()
@@ -87,8 +90,7 @@ typedef struct tr_metainfo_builder
 tr_metainfo_builder;
 
 
-tr_metainfo_builder*tr_metaInfoBuilderCreate( tr_session * session,
-                                              const char * topFile );
+tr_metainfo_builder*tr_metaInfoBuilderCreate( const char * topFile );
 
 void                tr_metaInfoBuilderFree( tr_metainfo_builder* );
 
@@ -117,4 +119,8 @@ void tr_makeMetaInfo( tr_metainfo_builder *   builder,
                       int                     isPrivate );
 
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
