@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: metainfo.c 8776 2009-07-03 14:37:27Z charles $
+ * $Id: metainfo.c 9829 2009-12-28 00:35:27Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -135,29 +135,29 @@ tr_metainfoMigrate( tr_session * session,
 ****
 ***/
 
-static int
-getfile( char        ** setme,
-         const char   * root,
-         tr_benc      * path )
+static tr_bool
+path_is_suspicious( const char * path )
 {
-    int err;
+    return ( path == NULL )
+        || ( strstr( path, "../" ) != NULL );
+}
 
-    if( !tr_bencIsList( path ) )
-    {
-        err = TR_EINVALID;
-    }
-    else
+static tr_bool
+getfile( char ** setme, const char * root, tr_benc * path )
+{
+    tr_bool success = FALSE;
+
+    if( tr_bencIsList( path ) )
     {
+        int i;
+        const int n = tr_bencListSize( path );
         struct evbuffer * buf = evbuffer_new( );
-        int               n = tr_bencListSize( path );
-        int               i;
 
         evbuffer_add( buf, root, strlen( root ) );
         for( i = 0; i < n; ++i )
         {
             const char * str;
-            if( tr_bencGetStr( tr_bencListChild( path, i ), &str )
-              && strcmp( str, ".." ) )
+            if( tr_bencGetStr( tr_bencListChild( path, i ), &str ) )
             {
                 evbuffer_add( buf, TR_PATH_DELIMITER_STR, 1 );
                 evbuffer_add( buf, str, strlen( str ) );
@@ -167,10 +167,17 @@ getfile( char        ** setme,
         *setme = tr_utf8clean( (char*)EVBUFFER_DATA( buf ), EVBUFFER_LENGTH( buf ), NULL );
         /* fprintf( stderr, "[%s]\n", *setme ); */
         evbuffer_free( buf );
-        err = 0;
+        success = TRUE;
     }
 
-    return err;
+    if( ( *setme != NULL ) && path_is_suspicious( *setme ) )
+    {
+        tr_free( *setme );
+        *setme = NULL;
+        success = FALSE;
+    }
+
+    return success;
 }
 
 static const char*
@@ -203,7 +210,7 @@ parseFiles( tr_info *       inf,
                 if( !tr_bencDictFindList( file, "path", &path ) )
                     return "path";
 
-            if( getfile( &inf->files[i].name, inf->name, path ) )
+            if( !getfile( &inf->files[i].name, inf->name, path ) )
                 return "path";
 
             if( !tr_bencDictFindInt( file, "length", &len ) )
@@ -215,6 +222,9 @@ parseFiles( tr_info *       inf,
     }
     else if( tr_bencGetInt( length, &len ) ) /* single-file mode */
     {
+        if( path_is_suspicious( inf->name ) )
+            return "path";
+
         inf->isMultifile      = 0;
         inf->fileCount        = 1;
         inf->files            = tr_new0( tr_file, 1 );
@@ -299,13 +309,13 @@ getannounce( tr_info * inf,
                         t->tier = validTiers;
                         t->announce = tr_strdup( url );
                         t->scrape = announceToScrape( url );
-                        
+
                         anyAdded = TRUE;
                     }
                     tr_free( url );
                 }
             }
-            
+
             if( anyAdded )
                 ++validTiers;
         }
@@ -461,20 +471,21 @@ tr_metainfoParseImpl( const tr_session * session,
     return NULL;
 }
 
-int
+tr_bool
 tr_metainfoParse( const tr_session * session,
-                  tr_info *         inf,
-                  const tr_benc *   meta_in )
+                  tr_info          * inf,
+                  const tr_benc    * meta_in )
 {
     const char * badTag = tr_metainfoParseImpl( session, inf, meta_in );
+    const tr_bool success = badTag == NULL;
 
     if( badTag )
     {
         tr_nerr( inf->name, _( "Invalid metadata entry \"%s\"" ), badTag );
         tr_metainfoFree( inf );
-        return TR_EINVALID;
     }
-    return 0;
+
+    return success;
 }
 
 void
