@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: metainfo.h 8637 2009-06-06 17:39:04Z charles $
+ * $Id: metainfo.h 8871 2009-08-05 01:59:16Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -33,9 +33,9 @@
 
 struct tr_benc;
 
-int  tr_metainfoParse( const tr_session     * session,
-                       tr_info              * info,
-                       const struct tr_benc * benc );
+tr_bool  tr_metainfoParse( const tr_session     * session,
+                           tr_info              * info,
+                           const struct tr_benc * benc );
 
 void tr_metainfoRemoveSaved( const tr_session * session,
                              const tr_info    * info );
