@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: natpmp.c 7658 2009-01-10 23:09:07Z charles $
+ * $Id: natpmp.c 9870 2010-01-04 22:15:01Z charles $
  */
 
 #include <assert.h>
@@ -81,6 +81,7 @@ tr_natpmpInit( void )
     nat = tr_new0( struct tr_natpmp, 1 );
     nat->state = TR_NATPMP_DISCOVER;
     nat->port = -1;
+    nat->natpmp.s = -1; /* socket */
     return nat;
 }
 
@@ -89,7 +90,8 @@ tr_natpmpClose( tr_natpmp * nat )
 {
     if( nat )
     {
-        closenatpmp( &nat->natpmp );
+        if( nat->natpmp.s >= 0 )
+            tr_netClose( nat->natpmp.s );
         tr_free( nat );
     }
 }
