@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: peer-io.h 7813 2009-01-29 18:18:24Z charles $
+ * $Id: peer-io.h 8903 2009-08-12 14:40:32Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -35,6 +35,11 @@ struct tr_bandwidth;
 struct tr_crypto;
 struct tr_peerIo;
 
+/**
+ * @addtogroup networked_io Networked IO
+ * @{
+ */
+
 typedef enum
 {
     READ_NOW,
@@ -63,12 +68,15 @@ typedef struct tr_peerIo
     tr_bool               peerIdIsSet;
     tr_bool               extendedProtocolSupported;
     tr_bool               fastExtensionSupported;
+    tr_bool               dhtSupported;
 
     /* we create the socket in a nonblocking way, so this flag is initially
      * false and then set to true when libevent says that the socket is ready
      * for reading or writing */
     tr_bool               hasFinishedConnecting;
 
+    tr_priority_t         priority;
+
     int                   pendingEvents;
 
     int                   magicNumber;
@@ -157,6 +165,15 @@ static TR_INLINE tr_bool tr_peerIoSupportsFEXT( const tr_peerIo * io )
     return io->fastExtensionSupported;
 }
 
+void        tr_peerIoEnableDHT( tr_peerIo * io, tr_bool flag );
+
+static TR_INLINE tr_bool tr_peerIoSupportsDHT( const tr_peerIo * io )
+{
+    assert( tr_isPeerIo( io ) );
+
+    return io->dhtSupported;
+}
+
 /**
 ***
 **/
@@ -373,11 +390,13 @@ static TR_INLINE double tr_peerIoGetPieceSpeed( const tr_peerIo * io, uint64_t n
 void      tr_peerIoSetEnabled( tr_peerIo    * io,
                                tr_direction   dir,
                                tr_bool        isEnabled );
-                       
+
 int       tr_peerIoFlush( tr_peerIo     * io,
                           tr_direction    dir,
                           size_t          byteLimit );
 
+int       tr_peerIoFlushOutgoingProtocolMsgs( tr_peerIo * io );
+
 /**
 ***
 **/
@@ -387,5 +406,6 @@ static TR_INLINE struct evbuffer * tr_peerIoGetReadBuffer( tr_peerIo * io )
     return io->inbuf;
 }
 
+/* @} */
 
 #endif
