@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: peer-mgr.h 8695 2009-06-15 00:11:06Z charles $
+ * $Id: peer-mgr.h 9086 2009-09-10 02:21:03Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -150,7 +150,8 @@ void tr_peerMgrSetBlame( tr_torrent        * tor,
 
 int  tr_peerMgrGetPeers( tr_torrent      * tor,
                          tr_pex         ** setme_pex,
-                         uint8_t           af);
+                         uint8_t           af,
+                         int               maxPeerCount );
 
 void tr_peerMgrStartTorrent( tr_torrent * tor );
 
