@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: peer-msgs.c 8963 2009-08-18 01:57:17Z charles $
+ * $Id: peer-msgs.c 9086 2009-09-10 02:21:03Z charles $
  */
 
 #include <assert.h>
@@ -69,7 +69,7 @@ enum
 
     TR_LTEP_PEX             = 1,
 
-
+    MAX_PEX_PEER_COUNT      = 100,
 
     MIN_CHOKE_PERIOD_SEC    = ( 10 ),
 
@@ -1975,8 +1975,8 @@ sendPex( tr_peermsgs * msgs )
         PexDiffs diffs6;
         tr_pex * newPex = NULL;
         tr_pex * newPex6 = NULL;
-        const int newCount = tr_peerMgrGetPeers( msgs->torrent, &newPex, TR_AF_INET );
-        const int newCount6 = tr_peerMgrGetPeers( msgs->torrent, &newPex6, TR_AF_INET6 );
+        const int newCount = tr_peerMgrGetPeers( msgs->torrent, &newPex, TR_AF_INET, MAX_PEX_PEER_COUNT );
+        const int newCount6 = tr_peerMgrGetPeers( msgs->torrent, &newPex6, TR_AF_INET6, MAX_PEX_PEER_COUNT );
 
         /* build the diffs */
         diffs.added = tr_new( tr_pex, newCount );
