@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: ptrarray.h 8637 2009-06-06 17:39:04Z charles $
+ * $Id: ptrarray.h 9110 2009-09-12 18:03:44Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -41,16 +41,9 @@ extern const tr_ptrArray TR_PTR_ARRAY_INIT;
 
 void          tr_ptrArrayDestruct( tr_ptrArray*, PtrArrayForeachFunc func );
 
-tr_ptrArray * tr_ptrArrayNew( void );
-
-tr_ptrArray * tr_ptrArrayDup( tr_ptrArray* );
-
 void          tr_ptrArrayForeach( tr_ptrArray         * array,
                                   PtrArrayForeachFunc   func );
 
-void          tr_ptrArrayFree( tr_ptrArray         * array,
-                               PtrArrayForeachFunc   func );
-
 void*         tr_ptrArrayNth( tr_ptrArray   * array,
                               int             nth );
 
@@ -72,10 +65,6 @@ static TR_INLINE int tr_ptrArrayAppend( tr_ptrArray * array, void * appendMe )
 
 void*         tr_ptrArrayPop( tr_ptrArray    * array );
 
-void          tr_ptrArrayErase( tr_ptrArray  * array,
-                                int            begin,
-                                int            end );
-
 static TR_INLINE void** tr_ptrArrayBase( const tr_ptrArray * a )
 {
     return a->items;
