@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: resume.h 7664 2009-01-11 17:46:51Z charles $
+ * $Id: resume.h 8254 2009-04-18 23:17:30Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -19,20 +19,22 @@
 
 enum
 {
-    TR_FR_DOWNLOADED     = ( 1 << 0 ),
-    TR_FR_UPLOADED       = ( 1 << 1 ),
-    TR_FR_CORRUPT        = ( 1 << 2 ),
-    TR_FR_PEERS          = ( 1 << 3 ),
-    TR_FR_PROGRESS       = ( 1 << 4 ),
-    TR_FR_DND            = ( 1 << 5 ),
-    TR_FR_PRIORITY       = ( 1 << 6 ),
-    TR_FR_SPEEDLIMIT     = ( 1 << 7 ),
-    TR_FR_RUN            = ( 1 << 8 ),
-    TR_FR_DOWNLOAD_DIR   = ( 1 << 9 ),
-    TR_FR_MAX_PEERS      = ( 1 << 10 ),
-    TR_FR_ADDED_DATE     = ( 1 << 11 ),
-    TR_FR_DONE_DATE      = ( 1 << 12 ),
-    TR_FR_ACTIVITY_DATE  = ( 1 << 13 )
+    TR_FR_DOWNLOADED          = ( 1 << 0 ),
+    TR_FR_UPLOADED            = ( 1 << 1 ),
+    TR_FR_CORRUPT             = ( 1 << 2 ),
+    TR_FR_PEERS               = ( 1 << 3 ),
+    TR_FR_PROGRESS            = ( 1 << 4 ),
+    TR_FR_DND                 = ( 1 << 5 ),
+    TR_FR_FILE_PRIORITIES     = ( 1 << 6 ),
+    TR_FR_BANDWIDTH_PRIORITY  = ( 1 << 7 ),
+    TR_FR_SPEEDLIMIT          = ( 1 << 8 ),
+    TR_FR_RUN                 = ( 1 << 9 ),
+    TR_FR_DOWNLOAD_DIR        = ( 1 << 10 ),
+    TR_FR_MAX_PEERS           = ( 1 << 11 ),
+    TR_FR_ADDED_DATE          = ( 1 << 12 ),
+    TR_FR_DONE_DATE           = ( 1 << 13 ),
+    TR_FR_ACTIVITY_DATE       = ( 1 << 14 ),
+    TR_FR_RATIOLIMIT          = ( 1 << 15 )
 };
 
 /**
