@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: rpc-server.h 7722 2009-01-16 17:31:10Z charles $
+ * $Id: rpc-server.h 8246 2009-04-16 19:14:37Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -46,22 +46,23 @@ tr_bool         tr_rpcGetWhitelistEnabled( const tr_rpc_server * server );
 void            tr_rpcSetWhitelist( tr_rpc_server * server,
                                     const char *    whitelist );
 
-char*           tr_rpcGetWhitelist( const tr_rpc_server * server );
+const char*     tr_rpcGetWhitelist( const tr_rpc_server * server );
 
 void            tr_rpcSetPassword( tr_rpc_server * server,
                                    const char *    password );
 
-char*           tr_rpcGetPassword( const tr_rpc_server * server );
+const char*     tr_rpcGetPassword( const tr_rpc_server * server );
 
 void            tr_rpcSetUsername( tr_rpc_server * server,
                                    const char *    username );
 
-char*           tr_rpcGetUsername( const tr_rpc_server * server );
+const char*     tr_rpcGetUsername( const tr_rpc_server * server );
 
 void            tr_rpcSetPasswordEnabled( tr_rpc_server * server,
                                           tr_bool         isEnabled );
 
 tr_bool         tr_rpcIsPasswordEnabled( const tr_rpc_server * session );
 
+const char*     tr_rpcGetBindAddress( const tr_rpc_server * server );
 
 #endif
