@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: tracker.c 8905 2009-08-12 20:12:52Z charles $
+ * $Id: tracker.c 9051 2009-09-07 06:19:26Z charles $
  */
 
 #include <assert.h>
@@ -524,7 +524,12 @@ onTrackerResponse( tr_session * session,
                                       responseCode,
                                       tr_webGetResponseStr( responseCode ) );
         tr_strlcpy( t->lastAnnounceStr, buf, sizeof( t->lastAnnounceStr ) );
-        publishWarning( t, buf );
+
+        /* if the repsonse may require intervention, notify the user; otherwise, just log it */ 
+        if( responseCode >= 400 ) 
+            publishWarning( t, buf ); 
+        tr_ninf( t->name, "%s", buf ); 
+
         tr_free( buf );
     }
     else
