@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: upnp.c 7869 2009-02-10 19:14:41Z charles $
+ * $Id: upnp.c 8767 2009-07-01 14:58:57Z charles $
  */
 
 #include <assert.h>
@@ -19,8 +19,8 @@
 #include "transmission.h"
 #include "port-forwarding.h"
 #include "session.h"
-#include "utils.h"
 #include "upnp.h"
+#include "utils.h"
 
 static const char *
 getKey( void ) { return _( "Port Forwarding (UPnP)" ); }
@@ -80,7 +80,8 @@ tr_upnpClose( tr_upnp * handle )
 int
 tr_upnpPulse( tr_upnp * handle,
               int       port,
-              int       isEnabled )
+              int       isEnabled,
+              int       doPortCheck )
 {
     int ret;
 
@@ -127,6 +128,24 @@ tr_upnpPulse( tr_upnp * handle,
             handle->state = TR_UPNP_UNMAP;
     }
 
+    if( isEnabled && handle->isMapped && doPortCheck )
+    {
+        char portStr[8];
+        char intPort[8];
+        char intClient[16];
+        int i;
+
+        tr_snprintf( portStr, sizeof( portStr ), "%d", handle->port );
+        i = UPNP_GetSpecificPortMappingEntry( handle->urls.controlURL,
+                                              handle->data.servicetype, portStr,
+                                              "TCP", intClient, intPort );
+        if( i != UPNPCOMMAND_SUCCESS )
+        {
+            tr_ninf( getKey( ), _( "Port %d isn't forwarded" ), handle->port );
+            handle->isMapped = FALSE;
+        }
+    }
+
     if( handle->state == TR_UPNP_UNMAP )
     {
         char portStr[16];
@@ -175,7 +194,7 @@ tr_upnpPulse( tr_upnp * handle,
                  handle->lanaddr, port );
         if( handle->isMapped )
         {
-            tr_ninf( getKey( ), _( "Port forwarding successful!" ) );
+            tr_ninf( getKey( ), "%s", _( "Port forwarding successful!" ) );
             handle->port = port;
             handle->state = TR_UPNP_IDLE;
         }
