@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: utils.c 8904 2009-08-12 19:44:32Z charles $
+ * $Id: utils.c 9360 2009-10-22 02:33:03Z charles $
  */
 
 #ifdef HAVE_MEMMEM
@@ -1328,8 +1328,9 @@ tr_parseNumberRange( const char * str_in, int len, int * setmeCount )
 double
 tr_truncd( double x, int decimal_places )
 {
-    const int i = (int) pow( 10, decimal_places );
-    double x2 = (int)(x*i);
+    static const int multiplier[] = { 1, 10, 100, 1000, 10000, 100000, 1000000, 10000000 };
+    const int64_t i = multiplier[decimal_places];
+    double x2 = (int64_t)(x*i);
     return x2 / i;
 }
 
