@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: Badger.h 6196 2008-06-15 04:57:41Z livings124 $
+ * $Id: Badger.h 7659 2009-01-10 23:37:37Z livings124 $
  *
- * Copyright (c) 2006-2008 Transmission authors and contributors
+ * Copyright (c) 2006-2009 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -27,18 +27,12 @@
 
 @interface Badger : NSObject
 {
-    tr_handle * fLib;
+    tr_session * fLib;
     
-    int fCompleted;
-    
-    //tiger-only fields
-    NSImage * fDockIcon, * fBadge;
-    NSDictionary * fAttributes;
-    int fCompletedBadged;
-    BOOL fSpeedBadge, fQuittingTiger;
+    NSUInteger fCompleted;
 }
 
-- (id) initWithLib: (tr_handle *) lib;
+- (id) initWithLib: (tr_session *) lib;
 
 - (void) updateBadge;
 - (void) incrementCompleted;
