@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: BlocklistDownloader.m 8040 2009-03-08 13:23:17Z titer $
+ * $Id: BlocklistDownloader.m 8866 2009-08-04 01:53:51Z livings124 $
  *
  * Copyright (c) 2008-2009 Transmission authors and contributors
  *
@@ -162,7 +162,7 @@ BlocklistDownloader * fDownloader = nil;
     
     [[NSNotificationCenter defaultCenter] postNotificationName: @"BlocklistUpdated" object: nil];
     
-    [pool release];
+    [pool drain];
     
     fDownloader = nil;
     [self release];
