@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: FilterButton.h 4423 2008-01-02 16:55:05Z livings124 $
+ * $Id: FilterButton.h 7659 2009-01-10 23:37:37Z livings124 $
  * 
- * Copyright (c) 2007-2008 Transmission authors and contributors
+ * Copyright (c) 2007-2009 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -26,9 +26,9 @@
 
 @interface FilterButton : NSButton
 {
-    int fCount;
+    NSUInteger fCount;
 }
 
-- (void) setCount: (int) count;
+- (void) setCount: (NSUInteger) count;
 
 @end
