@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: InfoWindowController.m 8841 2009-07-19 18:52:17Z livings124 $
+ * $Id: InfoWindowController.m 9002 2009-08-28 23:40:11Z livings124 $
  *
  * Copyright (c) 2006-2009 Transmission authors and contributors
  *
@@ -1686,7 +1686,7 @@ typedef enum
     
     [fTrackers insertObject: @"" atIndex: index];
     [fTrackerTable reloadData];
-    [fTrackerTable selectRow: index byExtendingSelection: NO];
+    [fTrackerTable selectRowIndexes: [NSIndexSet indexSetWithIndex: index] byExtendingSelection: NO];
     [fTrackerTable editColumn: 0 row: index withEvent: nil select: YES];
 }
 
