@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: PortChecker.h 6363 2008-07-19 14:32:11Z livings124 $
+ * $Id: PortChecker.h 7659 2009-01-10 23:37:37Z livings124 $
  *
- * Copyright (c) 2006-2008 Transmission authors and contributors
+ * Copyright (c) 2006-2009 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -36,7 +36,7 @@ typedef enum
 {    
     id fDelegate;
     port_status_t fStatus;
-    int fPortNumber;
+    NSInteger fPortNumber;
     
     NSURLConnection * fConnection;
     NSMutableData * fPortProbeData;
@@ -44,10 +44,9 @@ typedef enum
     NSTimer * fTimer;
 }
 
-- (id) initForPort: (int) portNumber withDelegate: (id) delegate;
+- (id) initForPort: (NSInteger) portNumber delay: (BOOL) delay withDelegate: (id) delegate;
 - (void) cancelProbe;
 
-- (void) callBackWithStatus: (port_status_t) status;
 - (port_status_t) status;
 
 @end
