@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: StatsWindowController.m 7666 2009-01-11 18:04:45Z livings124 $
+ * $Id: StatsWindowController.m 7983 2009-03-01 17:02:58Z livings124 $
  *
- * Copyright (c) 2007-2008 Transmission authors and contributors
+ * Copyright (c) 2007-2009 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -24,7 +24,6 @@
 
 #import "StatsWindowController.h"
 #import "NSStringAdditions.h"
-#import "NSApplicationAdditions.h"
 
 #define UPDATE_SECONDS 1.0
 
@@ -118,7 +117,7 @@ tr_session * fLib;
     [fResetButton sizeToFit];
     
     NSRect buttonFrame = [fResetButton frame];
-    buttonFrame.size.width += 10.0f;
+    buttonFrame.size.width += 10.0;
     buttonFrame.origin.x -= buttonFrame.size.width - oldButtonWidth;
     [fResetButton setFrame: buttonFrame];
 }
@@ -146,11 +145,7 @@ tr_session * fLib;
     [alert setAlertStyle: NSWarningAlertStyle];
     [alert addButtonWithTitle: NSLocalizedString(@"Reset", "Stats reset -> button")];
     [alert addButtonWithTitle: NSLocalizedString(@"Cancel", "Stats reset -> button")];
-    
-    if ([NSApp isOnLeopardOrBetter])
-        [alert setShowsSuppressionButton: YES];
-    else
-        [alert addButtonWithTitle: NSLocalizedString(@"Don't Alert Again", "Stats reset -> button")];
+    [alert setShowsSuppressionButton: YES];
     
     [alert beginSheetModalForWindow: [self window] modalDelegate: self
         didEndSelector: @selector(resetSheetClosed:returnCode:contextInfo:) contextInfo: nil];
@@ -210,7 +205,7 @@ tr_session * fLib;
 {
     [[alert window] orderOut: nil];
     
-    if (([NSApp isOnLeopardOrBetter] ? [[alert suppressionButton] state] == NSOnState : code == NSAlertThirdButtonReturn))
+    if ([[alert suppressionButton] state] == NSOnState)
         [[NSUserDefaults standardUserDefaults] setBool: NO forKey: @"WarningResetStats"];
     
     if (code == NSAlertFirstButtonReturn)
