@@ -7,13 +7,14 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: mainwin.cc 8890 2009-08-11 18:57:49Z charles $
+ * $Id: mainwin.cc 9367 2009-10-22 03:01:38Z charles $
  */
 
 #include <cassert>
 #include <iostream>
 
 #include <QCheckBox>
+#include <QCloseEvent>
 #include <QDesktopServices>
 #include <QFileDialog>
 #include <QLabel>
@@ -285,6 +286,23 @@ TrMainWindow :: ~TrMainWindow( )
 *****
 ****/
 
+void
+TrMainWindow :: closeEvent( QCloseEvent * event )
+{
+    // if they're using a tray icon, close to the tray
+    // instead of exiting
+    if( !myPrefs.getBool( Prefs :: SHOW_TRAY_ICON ) )
+        event->accept( );
+    else {
+        toggleWindows( false );
+        event->ignore( );
+    }
+}
+
+/****
+*****
+****/
+
 void
 TrMainWindow :: onSessionSourceChanged( )
 {
@@ -700,7 +718,7 @@ TrMainWindow :: refreshStatusBar( )
         str = tr( "Down: %1, Up: %2" ).arg( Utils :: sizeToString( stats.downloadedBytes ) )
                                       .arg( Utils :: sizeToString( stats.uploadedBytes ) );
     }
-    else /* default is "total-ratio" */
+    else // default is "total-ratio"
     {
         str = tr( "Ratio: %1" ).arg( Utils :: ratioToString( mySession.getCumulativeStats().ratio ) );
     }
@@ -719,21 +737,23 @@ TrMainWindow :: refreshActionSensitivity( )
     const QItemSelectionModel * selectionModel( ui.listView->selectionModel( ) );
     const int rowCount( model->rowCount( ) );
 
-    /* count how many torrents are selected, paused, etc */
+    // count how many torrents are selected, paused, etc
     for( int row=0; row<rowCount; ++row ) {
         const QModelIndex modelIndex( model->index( row, 0 ) );
         assert( model == modelIndex.model( ) );
         const Torrent * tor( model->data( modelIndex, TorrentModel::TorrentRole ).value<const Torrent*>( ) );
-        const bool isSelected( selectionModel->isSelected( modelIndex ) );
-        const bool isPaused( tor->isPaused( ) );
-        if( isSelected )
-            ++selected;
-        if( isPaused )
-            ++ paused;
-        if( isSelected && isPaused )
-            ++selectedAndPaused;
-        if( tor->canManualAnnounce( ) )
-            ++canAnnounce;
+        if( tor ) {
+            const bool isSelected( selectionModel->isSelected( modelIndex ) );
+            const bool isPaused( tor->isPaused( ) );
+            if( isSelected )
+                ++selected;
+            if( isPaused )
+                ++ paused;
+            if( isSelected && isPaused )
+                ++selectedAndPaused;
+            if( tor->canManualAnnounce( ) )
+                ++canAnnounce;
+        }
     }
 
     const bool haveSelection( selected > 0 );
